package
Version:
v0.0.0-...-d868ca6
Opens a new window with list of versions in this module.
Published: May 14, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func CommentSectionMetaBlock(url, domain, author, timeAgo string, ...) string
-
func ReaderModeMetaBlock(url, author, timeAgo string, id, points int, enableNerdFonts bool, width int) string
func CommentSectionMetaBlock(url, domain, author, timeAgo string, id, commentsCount, points, newComments int, enableNerdFonts bool, rootComment string, width int) string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.